==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/sagemaker/WorkteamReference.java <==
package software.amazon.awscdk.interfaces.sagemaker;

/**
 * A reference to a Workteam resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.sagemaker.*;
 * WorkteamReference workteamReference = WorkteamReference.builder()
 *         .workteamId("workteamId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:03.939Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_sagemaker.WorkteamReference")
@software.amazon.jsii.Jsii.Proxy(WorkteamReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface WorkteamReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the Workteam resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getWorkteamId();

    /**
     * @return a {@link Builder} of {@link WorkteamReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WorkteamReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<WorkteamReference> {
        java.lang.String workteamId;

        /**
         * Sets the value of {@link WorkteamReference#getWorkteamId}
         * @param workteamId The Id of the Workteam resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder workteamId(java.lang.String workteamId) {
            this.workteamId = workteamId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WorkteamReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public WorkteamReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WorkteamReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WorkteamReference {
        private final java.lang.String workteamId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.workteamId = software.amazon.jsii.Kernel.get(this, "workteamId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.workteamId = java.util.Objects.requireNonNull(builder.workteamId, "workteamId is required");
        }

        @Override
        public final java.lang.String getWorkteamId() {
            return this.workteamId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("workteamId", om.valueToTree(this.getWorkteamId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_sagemaker.WorkteamReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WorkteamReference.Jsii$Proxy that = (WorkteamReference.Jsii$Proxy) o;

            return this.workteamId.equals(that.workteamId);
        }

        @Override
        public final int hashCode() {
            int result = this.workteamId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/sagemaker/WorkteamReference.java <==
package software.amazon.awscdk.interfaces.sagemaker;

/**
 * A reference to a Workteam resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.sagemaker.*;
 * WorkteamReference workteamReference = WorkteamReference.builder()
 *         .workteamId("workteamId")
 *         .workteamName("workteamName")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.155Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_sagemaker.WorkteamReference")
@software.amazon.jsii.Jsii.Proxy(WorkteamReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface WorkteamReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Id of the Workteam resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getWorkteamId();

    /**
     * The WorkteamName of the Workteam resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getWorkteamName();

    /**
     * @return a {@link Builder} of {@link WorkteamReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WorkteamReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<WorkteamReference> {
        java.lang.String workteamId;
        java.lang.String workteamName;

        /**
         * Sets the value of {@link WorkteamReference#getWorkteamId}
         * @param workteamId The Id of the Workteam resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder workteamId(java.lang.String workteamId) {
            this.workteamId = workteamId;
            return this;
        }

        /**
         * Sets the value of {@link WorkteamReference#getWorkteamName}
         * @param workteamName The WorkteamName of the Workteam resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder workteamName(java.lang.String workteamName) {
            this.workteamName = workteamName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WorkteamReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public WorkteamReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link WorkteamReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WorkteamReference {
        private final java.lang.String workteamId;
        private final java.lang.String workteamName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.workteamId = software.amazon.jsii.Kernel.get(this, "workteamId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.workteamName = software.amazon.jsii.Kernel.get(this, "workteamName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.workteamId = java.util.Objects.requireNonNull(builder.workteamId, "workteamId is required");
            this.workteamName = java.util.Objects.requireNonNull(builder.workteamName, "workteamName is required");
        }

        @Override
        public final java.lang.String getWorkteamId() {
            return this.workteamId;
        }

        @Override
        public final java.lang.String getWorkteamName() {
            return this.workteamName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("workteamId", om.valueToTree(this.getWorkteamId()));
            data.set("workteamName", om.valueToTree(this.getWorkteamName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_sagemaker.WorkteamReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WorkteamReference.Jsii$Proxy that = (WorkteamReference.Jsii$Proxy) o;

            if (!workteamId.equals(that.workteamId)) return false;
            return this.workteamName.equals(that.workteamName);
        }

        @Override
        public final int hashCode() {
            int result = this.workteamId.hashCode();
            result = 31 * result + (this.workteamName.hashCode());
            return result;
        }
    }
}
